;; Generated package description from triples.el  -*- no-byte-compile: t -*-
(define-package "triples" "0.2" "A flexible triple-based database for us in apps." '((seq "2.0") (emacs "25")) :commit "ac12a6b7feb665c7ac80aebdf44523024a8e5c92" :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :keywords '("triples" "kg" "data" "sqlite") :url "https://github.com/ahyatt/triples")
